@@ -10,6 +10,7 @@ class utility:
 
     def boto_session(self,aws_secret_access_key,aws_access_key_id,aws_session_token,region_name):
         global session
+        global region
         session = boto3.session.Session(
         aws_access_key_id=aws_secret_access_key,
         aws_secret_access_key=aws_access_key_id,
@@ -54,4 +55,35 @@ class utility:
             
 
         df = pd.DataFrame(result)
-        df.to_csv ('report.csv', index = None)
+        df.to_csv ('_iam_userlist.csv', index = None)
+
+        def ebs_volume_report(self):
+
+            ec2_client = session.client('ec2')
+
+            paginator = ec2_client.get_paginator('describe_volumes')
+
+            response_iterator = paginator.paginate()
+            header = ['InstanceId','VolumeID', 'Size(GB)', 'Availability Zone','Volume Type','Status','IOPS']
+            with open('ebs_report_+'region+'.csv','w', newline = '') as csvfile:
+                writer = csv.writer(csvfile)
+                writer.writerow(header)
+                for page in response_iterator:
+                cnt = 1
+                for  volume in page['Volumes']:
+
+                    print(cnt)
+                    for att in volume['Attachments']:
+                        print('Instance ID =', att['InstanceId'])
+                        inst = att['InstanceId']
+                    print('Volume ID = ', volume['VolumeId']) 
+                    print('Volume Size =' , volume['Size'],"GB")
+                    print("AvailabilityZone = ", volume['AvailabilityZone'])
+                    print("Volume Type = ", volume['VolumeType'])
+                    print("Volume Status =", volume['State'])
+                    #print("IOPS =", volume['Iops'])
+                    print("--------")
+                    cnt = cnt + 1
+                    data = [inst,volume['VolumeId'],volume['Size'],volume['AvailabilityZone'],volume['VolumeType'],volume['State'],volume['Iops']]
+
+                    writer.writerow(data)
